@@ -16,6 +16,7 @@ except ImportError:
                     return default
     settings = Settings()
 
+import os
 import json
 import requests
 from requests.auth import HTTPBasicAuth
@@ -29,11 +30,22 @@ def request(url, method, **kw):
 
     api_user = kw.pop('api_user', settings.ACTIONKIT_API_USER)
     api_password = kw.pop('api_password', settings.ACTIONKIT_API_PASSWORD)
-        
-    return getattr(requests, method)(
-        url, allow_redirects=False, 
-        auth=(api_user, api_password),
-        **kw)
+
+    if 'FIXIE_URL' in os.environ:
+        proxyDict = {
+            "http"  : os.environ.get('FIXIE_URL', ''),
+            "https" : os.environ.get('FIXIE_URL', '')
+        }
+        return getattr(requests, method)(
+            url, allow_redirects=False, 
+            auth=(api_user, api_password),
+            proxies=proxyDict,
+            **kw)
+    else:
+        return getattr(requests, method)(
+            url, allow_redirects=False, 
+            auth=(api_user, api_password),
+            **kw)
 
 class client(object):
     def __init__(
@@ -152,7 +164,25 @@ class ClientResourceHandler(object):
         self.check_method("delete")
         resp = request(self.base_url + "%s/" % id, "delete", api_user=self.api_user, api_password=self.api_password)        
         assert resp.status_code == 204, (resp, resp.text)
+
+    def request(self, path, **kw):
+        resp = request(self.base_url + path, "get", params=kw, api_user=self.api_user, api_password=self.api_password)
+        assert resp.status_code == 200, (resp, resp.text)        
+        return resp.json()
+
+    def fetch_all(self, path, **kw):
+        objects = []
+        kw['_limit'] = 100
+        resp = self.request(path, **kw)
+        objects.extend(resp.get('objects', []))
         
+        while resp.get('meta', {}).get('next'):
+            kw['_offset'] = resp['meta']['offset'] + 100
+            resp = self.request(path, **kw)
+            objects.extend(resp.get('objects', []))            
+
+        return objects
+
     def list(self, **kw):
         self.check_collection_method("get")
         resp = request(self.base_url, "get", params=kw, api_user=self.api_user, api_password=self.api_password)        
